@@ -108,7 +108,7 @@ class Exceptions:
 
 class CostExplorerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html)
     """
 
@@ -124,7 +124,7 @@ class CostExplorerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#can_paginate)
         """
 
@@ -135,7 +135,7 @@ class CostExplorerClient(BaseClient):
         Creates a new cost anomaly detection monitor with the requested type and monitor
         specification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_anomaly_monitor)
         """
 
@@ -145,7 +145,7 @@ class CostExplorerClient(BaseClient):
         """
         Adds a subscription to a cost anomaly detection monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_anomaly_subscription)
         """
 
@@ -155,13 +155,13 @@ class CostExplorerClient(BaseClient):
         Name: str,
         RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: Sequence["CostCategoryRuleTypeDef"],
-        DefaultValue: str = None,
-        SplitChargeRules: Sequence["CostCategorySplitChargeRuleTypeDef"] = None
+        DefaultValue: str = ...,
+        SplitChargeRules: Sequence["CostCategorySplitChargeRuleTypeDef"] = ...
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
         Creates a new Cost Category with the requested name and rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_cost_category_definition)
         """
 
@@ -169,7 +169,7 @@ class CostExplorerClient(BaseClient):
         """
         Deletes a cost anomaly monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_anomaly_monitor)
         """
 
@@ -177,7 +177,7 @@ class CostExplorerClient(BaseClient):
         """
         Deletes a cost anomaly subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_anomaly_subscription)
         """
 
@@ -187,32 +187,32 @@ class CostExplorerClient(BaseClient):
         """
         Deletes a Cost Category.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_cost_category_definition)
         """
 
     def describe_cost_category_definition(
-        self, *, CostCategoryArn: str, EffectiveOn: str = None
+        self, *, CostCategoryArn: str, EffectiveOn: str = ...
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
         Returns the name, ARN, rules, definition, and effective dates of a Cost Category
         that's defined in the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#describe_cost_category_definition)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#generate_presigned_url)
         """
 
@@ -220,46 +220,46 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         DateInterval: "AnomalyDateIntervalTypeDef",
-        MonitorArn: str = None,
-        Feedback: AnomalyFeedbackTypeType = None,
-        TotalImpact: "TotalImpactFilterTypeDef" = None,
-        NextPageToken: str = None,
-        MaxResults: int = None
+        MonitorArn: str = ...,
+        Feedback: AnomalyFeedbackTypeType = ...,
+        TotalImpact: "TotalImpactFilterTypeDef" = ...,
+        NextPageToken: str = ...,
+        MaxResults: int = ...
     ) -> GetAnomaliesResponseTypeDef:
         """
         Retrieves all of the cost anomalies detected on your account during the time
         period that's specified by the `DateInterval` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_anomalies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomalies)
         """
 
     def get_anomaly_monitors(
         self,
         *,
-        MonitorArnList: Sequence[str] = None,
-        NextPageToken: str = None,
-        MaxResults: int = None
+        MonitorArnList: Sequence[str] = ...,
+        NextPageToken: str = ...,
+        MaxResults: int = ...
     ) -> GetAnomalyMonitorsResponseTypeDef:
         """
         Retrieves the cost anomaly monitor definitions for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomaly_monitors)
         """
 
     def get_anomaly_subscriptions(
         self,
         *,
-        SubscriptionArnList: Sequence[str] = None,
-        MonitorArn: str = None,
-        NextPageToken: str = None,
-        MaxResults: int = None
+        SubscriptionArnList: Sequence[str] = ...,
+        MonitorArn: str = ...,
+        NextPageToken: str = ...,
+        MaxResults: int = ...
     ) -> GetAnomalySubscriptionsResponseTypeDef:
         """
         Retrieves the cost anomaly subscription objects for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomaly_subscriptions)
         """
 
@@ -269,14 +269,14 @@ class CostExplorerClient(BaseClient):
         TimePeriod: "DateIntervalTypeDef",
         Granularity: GranularityType,
         Metrics: Sequence[str],
-        Filter: "ExpressionTypeDef" = None,
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = None,
-        NextPageToken: str = None
+        Filter: "ExpressionTypeDef" = ...,
+        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        NextPageToken: str = ...
     ) -> GetCostAndUsageResponseTypeDef:
         """
         Retrieves cost and usage metrics for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_and_usage)
         """
 
@@ -286,14 +286,14 @@ class CostExplorerClient(BaseClient):
         TimePeriod: "DateIntervalTypeDef",
         Granularity: GranularityType,
         Filter: "ExpressionTypeDef",
-        Metrics: Sequence[str] = None,
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = None,
-        NextPageToken: str = None
+        Metrics: Sequence[str] = ...,
+        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        NextPageToken: str = ...
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
         Retrieves cost and usage metrics with resources for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_and_usage_with_resources)
         """
 
@@ -301,17 +301,17 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         TimePeriod: "DateIntervalTypeDef",
-        SearchString: str = None,
-        CostCategoryName: str = None,
-        Filter: "ExpressionTypeDef" = None,
-        SortBy: Sequence["SortDefinitionTypeDef"] = None,
-        MaxResults: int = None,
-        NextPageToken: str = None
+        SearchString: str = ...,
+        CostCategoryName: str = ...,
+        Filter: "ExpressionTypeDef" = ...,
+        SortBy: Sequence["SortDefinitionTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextPageToken: str = ...
     ) -> GetCostCategoriesResponseTypeDef:
         """
         Retrieves an array of Cost Category names and values incurred cost.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_categories)
         """
 
@@ -321,14 +321,14 @@ class CostExplorerClient(BaseClient):
         TimePeriod: "DateIntervalTypeDef",
         Metric: MetricType,
         Granularity: GranularityType,
-        Filter: "ExpressionTypeDef" = None,
-        PredictionIntervalLevel: int = None
+        Filter: "ExpressionTypeDef" = ...,
+        PredictionIntervalLevel: int = ...
     ) -> GetCostForecastResponseTypeDef:
         """
         Retrieves a forecast for how much Amazon Web Services predicts that you will
         spend over the forecast time period that you select, based on your past costs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_forecast)
         """
 
@@ -337,18 +337,18 @@ class CostExplorerClient(BaseClient):
         *,
         TimePeriod: "DateIntervalTypeDef",
         Dimension: DimensionType,
-        SearchString: str = None,
-        Context: ContextType = None,
-        Filter: "ExpressionTypeDef" = None,
-        SortBy: Sequence["SortDefinitionTypeDef"] = None,
-        MaxResults: int = None,
-        NextPageToken: str = None
+        SearchString: str = ...,
+        Context: ContextType = ...,
+        Filter: "ExpressionTypeDef" = ...,
+        SortBy: Sequence["SortDefinitionTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextPageToken: str = ...
     ) -> GetDimensionValuesResponseTypeDef:
         """
         Retrieves all available filter values for a specified filter over a period of
         time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_dimension_values)
         """
 
@@ -356,18 +356,18 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         TimePeriod: "DateIntervalTypeDef",
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = None,
-        Granularity: GranularityType = None,
-        Filter: "ExpressionTypeDef" = None,
-        Metrics: Sequence[str] = None,
-        NextPageToken: str = None,
-        SortBy: "SortDefinitionTypeDef" = None,
-        MaxResults: int = None
+        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        Granularity: GranularityType = ...,
+        Filter: "ExpressionTypeDef" = ...,
+        Metrics: Sequence[str] = ...,
+        NextPageToken: str = ...,
+        SortBy: "SortDefinitionTypeDef" = ...,
+        MaxResults: int = ...
     ) -> GetReservationCoverageResponseTypeDef:
         """
         Retrieves the reservation coverage for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_coverage)
         """
 
@@ -375,20 +375,20 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         Service: str,
-        AccountId: str = None,
-        Filter: "ExpressionTypeDef" = None,
-        AccountScope: AccountScopeType = None,
-        LookbackPeriodInDays: LookbackPeriodInDaysType = None,
-        TermInYears: TermInYearsType = None,
-        PaymentOption: PaymentOptionType = None,
-        ServiceSpecification: "ServiceSpecificationTypeDef" = None,
-        PageSize: int = None,
-        NextPageToken: str = None
+        AccountId: str = ...,
+        Filter: "ExpressionTypeDef" = ...,
+        AccountScope: AccountScopeType = ...,
+        LookbackPeriodInDays: LookbackPeriodInDaysType = ...,
+        TermInYears: TermInYearsType = ...,
+        PaymentOption: PaymentOptionType = ...,
+        ServiceSpecification: "ServiceSpecificationTypeDef" = ...,
+        PageSize: int = ...,
+        NextPageToken: str = ...
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
         Gets recommendations for which reservations to purchase.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_purchase_recommendation)
         """
 
@@ -396,17 +396,17 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         TimePeriod: "DateIntervalTypeDef",
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = None,
-        Granularity: GranularityType = None,
-        Filter: "ExpressionTypeDef" = None,
-        SortBy: "SortDefinitionTypeDef" = None,
-        NextPageToken: str = None,
-        MaxResults: int = None
+        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        Granularity: GranularityType = ...,
+        Filter: "ExpressionTypeDef" = ...,
+        SortBy: "SortDefinitionTypeDef" = ...,
+        NextPageToken: str = ...,
+        MaxResults: int = ...
     ) -> GetReservationUtilizationResponseTypeDef:
         """
         Retrieves the reservation utilization for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_utilization)
         """
 
@@ -414,16 +414,16 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         Service: str,
-        Filter: "ExpressionTypeDef" = None,
-        Configuration: "RightsizingRecommendationConfigurationTypeDef" = None,
-        PageSize: int = None,
-        NextPageToken: str = None
+        Filter: "ExpressionTypeDef" = ...,
+        Configuration: "RightsizingRecommendationConfigurationTypeDef" = ...,
+        PageSize: int = ...,
+        NextPageToken: str = ...
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
         Creates recommendations that help you save cost by identifying idle and
         underutilized Amazon EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_rightsizing_recommendation)
         """
 
@@ -431,18 +431,18 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         TimePeriod: "DateIntervalTypeDef",
-        GroupBy: Sequence["GroupDefinitionTypeDef"] = None,
-        Granularity: GranularityType = None,
-        Filter: "ExpressionTypeDef" = None,
-        Metrics: Sequence[str] = None,
-        NextToken: str = None,
-        MaxResults: int = None,
-        SortBy: "SortDefinitionTypeDef" = None
+        GroupBy: Sequence["GroupDefinitionTypeDef"] = ...,
+        Granularity: GranularityType = ...,
+        Filter: "ExpressionTypeDef" = ...,
+        Metrics: Sequence[str] = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        SortBy: "SortDefinitionTypeDef" = ...
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
         Retrieves the Savings Plans covered for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_coverage)
         """
 
@@ -453,16 +453,16 @@ class CostExplorerClient(BaseClient):
         TermInYears: TermInYearsType,
         PaymentOption: PaymentOptionType,
         LookbackPeriodInDays: LookbackPeriodInDaysType,
-        AccountScope: AccountScopeType = None,
-        NextPageToken: str = None,
-        PageSize: int = None,
-        Filter: "ExpressionTypeDef" = None
+        AccountScope: AccountScopeType = ...,
+        NextPageToken: str = ...,
+        PageSize: int = ...,
+        Filter: "ExpressionTypeDef" = ...
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
         Retrieves your request parameters, Savings Plan Recommendations Summary and
         Details.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_purchase_recommendation)
         """
 
@@ -470,15 +470,15 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         TimePeriod: "DateIntervalTypeDef",
-        Granularity: GranularityType = None,
-        Filter: "ExpressionTypeDef" = None,
-        SortBy: "SortDefinitionTypeDef" = None
+        Granularity: GranularityType = ...,
+        Filter: "ExpressionTypeDef" = ...,
+        SortBy: "SortDefinitionTypeDef" = ...
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
         Retrieves the Savings Plans utilization for your account across date ranges with
         daily or monthly granularity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_utilization)
         """
 
@@ -486,17 +486,17 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         TimePeriod: "DateIntervalTypeDef",
-        Filter: "ExpressionTypeDef" = None,
-        DataType: Sequence[SavingsPlansDataTypeType] = None,
-        NextToken: str = None,
-        MaxResults: int = None,
-        SortBy: "SortDefinitionTypeDef" = None
+        Filter: "ExpressionTypeDef" = ...,
+        DataType: Sequence[SavingsPlansDataTypeType] = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        SortBy: "SortDefinitionTypeDef" = ...
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
         Retrieves attribute data along with aggregate utilization and savings data for a
         given time period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_utilization_details)
         """
 
@@ -504,17 +504,17 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         TimePeriod: "DateIntervalTypeDef",
-        SearchString: str = None,
-        TagKey: str = None,
-        Filter: "ExpressionTypeDef" = None,
-        SortBy: Sequence["SortDefinitionTypeDef"] = None,
-        MaxResults: int = None,
-        NextPageToken: str = None
+        SearchString: str = ...,
+        TagKey: str = ...,
+        Filter: "ExpressionTypeDef" = ...,
+        SortBy: Sequence["SortDefinitionTypeDef"] = ...,
+        MaxResults: int = ...,
+        NextPageToken: str = ...
     ) -> GetTagsResponseTypeDef:
         """
         Queries for available tag keys and tag values for a specified period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_tags)
         """
 
@@ -524,25 +524,25 @@ class CostExplorerClient(BaseClient):
         TimePeriod: "DateIntervalTypeDef",
         Metric: MetricType,
         Granularity: GranularityType,
-        Filter: "ExpressionTypeDef" = None,
-        PredictionIntervalLevel: int = None
+        Filter: "ExpressionTypeDef" = ...,
+        PredictionIntervalLevel: int = ...
     ) -> GetUsageForecastResponseTypeDef:
         """
         Retrieves a forecast for how much Amazon Web Services predicts that you will use
         over the forecast time period that you select, based on your past usage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_usage_forecast)
         """
 
     def list_cost_category_definitions(
-        self, *, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
+        self, *, EffectiveOn: str = ..., NextToken: str = ..., MaxResults: int = ...
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
         Returns the name, ARN, `NumberOfRules` and effective dates of all Cost
         Categories defined in the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#list_cost_category_definitions)
         """
 
@@ -552,17 +552,17 @@ class CostExplorerClient(BaseClient):
         """
         Modifies the feedback property of a given cost anomaly.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#provide_anomaly_feedback)
         """
 
     def update_anomaly_monitor(
-        self, *, MonitorArn: str, MonitorName: str = None
+        self, *, MonitorArn: str, MonitorName: str = ...
     ) -> UpdateAnomalyMonitorResponseTypeDef:
         """
         Updates an existing cost anomaly monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_anomaly_monitor)
         """
 
@@ -570,16 +570,16 @@ class CostExplorerClient(BaseClient):
         self,
         *,
         SubscriptionArn: str,
-        Threshold: float = None,
-        Frequency: AnomalySubscriptionFrequencyType = None,
-        MonitorArnList: Sequence[str] = None,
-        Subscribers: Sequence["SubscriberTypeDef"] = None,
-        SubscriptionName: str = None
+        Threshold: float = ...,
+        Frequency: AnomalySubscriptionFrequencyType = ...,
+        MonitorArnList: Sequence[str] = ...,
+        Subscribers: Sequence["SubscriberTypeDef"] = ...,
+        SubscriptionName: str = ...
     ) -> UpdateAnomalySubscriptionResponseTypeDef:
         """
         Updates an existing cost anomaly monitor subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_anomaly_subscription)
         """
 
@@ -589,12 +589,12 @@ class CostExplorerClient(BaseClient):
         CostCategoryArn: str,
         RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: Sequence["CostCategoryRuleTypeDef"],
-        DefaultValue: str = None,
-        SplitChargeRules: Sequence["CostCategorySplitChargeRuleTypeDef"] = None
+        DefaultValue: str = ...,
+        SplitChargeRules: Sequence["CostCategorySplitChargeRuleTypeDef"] = ...
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
         Updates an existing Cost Category.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_cost_category_definition)
         """
